@@ -847,7 +847,7 @@ void TextSelectable::update( void)
 {
     _prevSize = _size;
     _size += _ds;
-    Clamp( _size, 1.0, 2.0);
+    Clamp( _size, 1.0, 1.8); //any bigger and we'll have overlapping activation areas
 
     //adjust the input box according to the scaled text
     float dx = (float)(_boundingBox.max.x - _boundingBox.min.x) * (_size-1.0f) / 2.0f;
